"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var EventBus_1 = require("./EventBus");
var PlaybackStateTracker_1 = require("./PlaybackStateTracker");
var react_resize_detector_1 = require("react-resize-detector");
var StreamPlayback_1 = require("./StreamPlayback");
require("./styles/BoclipsPlayer.less");
var YoutubePlayback_1 = require("./YoutubePlayback");
var VIDEO_PLAY_EVENT = 'VIDEO_PLAY';
var Player = /** @class */ (function (_super) {
    __extends(Player, _super);
    function Player(props) {
        var _this = _super.call(this, props) || this;
        _this.tracker = null;
        _this.videoRef = null;
        _this.onPlayerResize = function (_, height) {
            var fontSize = Math.max(0.04445 * height, 12);
            _this.setState({ fontSize: fontSize });
        };
        _this.tracker = new PlaybackStateTracker_1.default(_this.props.trackerConfig, _this.props.playbackConfig.durationSeconds);
        _this.videoRef = React.createRef();
        _this.state = {
            fontSize: 12
        };
        return _this;
    }
    Player.prototype.getControls = function () {
        return this.props.controls ? this.props.controls : PlayerControls.DEFAULT;
    };
    Player.prototype.render = function () {
        var playerContent;
        playerContent = this.renderPlayback();
        return (React.createElement("section", { className: "boclips-player", style: { fontSize: this.state.fontSize } },
            playerContent,
            React.createElement(react_resize_detector_1.default, { handleWidth: true, handleHeight: true, onResize: this.onPlayerResize })));
    };
    Player.prototype.componentDidMount = function () {
        EventBus_1.default.getInstance().on(VIDEO_PLAY_EVENT, this.videoPlayListener, this);
    };
    Player.prototype.componentWillUnmount = function () {
        EventBus_1.default.getInstance().off(VIDEO_PLAY_EVENT, this.videoPlayListener, this);
    };
    Player.prototype.renderPlayback = function () {
        if (this.props.playbackConfig.type === 'YOUTUBE') {
            return (React.createElement(YoutubePlayback_1.YoutubePlayback, { youtubeId: this.props.playbackConfig.youtubeId, tracker: this.tracker, videoRef: this.videoRef, onPlay: this.onPlay, controls: this.getControls() }));
        }
        return (React.createElement(StreamPlayback_1.StreamPlayback, { stream: this.props.playbackConfig.stream, tracker: this.tracker, thumbnailUrl: this.props.thumbnail, videoRef: this.videoRef, onPlay: this.onPlay, controls: this.getControls() }));
    };
    Player.prototype.onPlay = function () {
        EventBus_1.default.getInstance().emit(VIDEO_PLAY_EVENT, { videoRef: this.videoRef });
    };
    Player.prototype.videoPlayListener = function (event) {
        if (event.videoRef.current !== this.videoRef.current) {
            this.videoRef.current.plyr.pause();
        }
    };
    return Player;
}(React.Component));
exports.Player = Player;
var PlayerControls = /** @class */ (function () {
    function PlayerControls() {
    }
    PlayerControls.DEFAULT = [
        'play-large',
        'play',
        'progress',
        'current-time',
        'mute',
        'volume',
        'captions',
        'fullscreen',
    ];
    PlayerControls.THUMBNAIL = ['play-large', 'mute', 'volume'];
    PlayerControls.BIG_PLAY_ONLY = ['play-large'];
    PlayerControls.NO_CONTROLS = [];
    return PlayerControls;
}());
exports.PlayerControls = PlayerControls;
//# sourceMappingURL=Player.js.map